@@ -4,6 +4,9 @@ import json
 
 
 class DataLake(ABC):
+    """
+    base class, contains generic methods
+    """
     events = None
     string_validate_columns = ""
     input_data = ""
@@ -14,6 +17,22 @@ class DataLake(ABC):
 
     def __init__(self, spark, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
                  storage_silver, input_data_param, mount_data_param, colums_validate_merge_param, new_name, database, target, origin):
+        """
+        set object variables
+        :param spark: spark instance
+        :param storage_account_name: storage account azure
+        :param storage_account_access_key: storage access key azure
+        :param storage_landing: storage account landing
+        :param storage_bronze: storage account bronze
+        :param storage_silver: storage account silver
+        :param input_data_param: path and filename in the source data lake
+        :param mount_data_param: path and filename in the destination data lake
+        :param colums_validate_merge_param: columns representing single record separated by comma (Id,)
+        :param new_name: new table name in destination
+        :param database: source database
+        :param target: information destination
+        :param origin: origin of the information
+        """
         self.spark = spark
         self.storage_account_name=storage_account_name
         self.storage_account_access_key=storage_account_access_key
@@ -43,11 +62,19 @@ class DataLake(ABC):
         pass
 
     def initialize_config_storage(self):
+        """
+        connection with the data lake is created
+        :return: connected object
+        """
         self.spark.conf.set(
             "fs.azure.account.key." + self.storage_account_name + ".blob.core.windows.net",
             self.storage_account_access_key)
 
     def validate_tables(self):
+        """
+        it is validated if a table exists in the database
+        :return: True if the table exists or False if it doesn't exist in table_exist
+        """
         list_tables = self.spark.catalog.listTables(self.database)
         self.table_exist = False
         for item in list_tables:
@@ -59,9 +86,18 @@ class DataLake(ABC):
                 break
 
     def load_data_csv(self, input_data):
+        """
+        method that loads csv files
+        :param input_data: path in the data lake of the file to load
+        :return: the object with the file data in events
+        """
         self.events = self.spark.read.format("csv").option("header", "true").load(input_data)
 
     def create_colums_merge(self):
+        """
+        method creates the condition to perform the merge with an array of fields containing the registry keys
+        :return: condition to perform the merge in string_validate_columns
+        """
         self.string_validate_columns = ""
         string_and = "and"
         for item in self.colums_validate_merge:
@@ -74,6 +110,10 @@ class DataLake(ABC):
         print(self.string_validate_columns)
 
     def create_json_columns_pass(self):
+        """
+        method that creates json with the columns to pass to the next zone
+        :return: json with columns to pass in json_load_insert_values
+        """
         insert_values = "{"
         for item in self.colums_silver_array:
             if item is not "":
